modules

package
v0.7.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package modules registers built-in runtime modules for the API process.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func All

func All() []app.Module

All returns the complete runtime module list in registration order.

Types

This section is empty.

Directories

Path Synopsis
Package health exposes liveness and readiness endpoints as an app module.
Package health exposes liveness and readiness endpoints as an app module.
Package system provides system-level example routes, auth demos, and utility endpoints.
Package system provides system-level example routes, auth demos, and utility endpoints.

Jump to