Documentation
¶
Overview ¶
Package validator statically validates route policy wiring for SuperAPI modules.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Diagnostic ¶
type Diagnostic struct {
// File is source file containing the issue.
File string `json:"file"`
// Line is source line for the route declaration.
Line int `json:"line"`
// Message describes violated validation rule.
Message string `json:"message"`
}
Diagnostic reports one static route-policy validation issue.
func AnalyzePaths ¶
func AnalyzePaths(paths []string) ([]Diagnostic, error)
AnalyzePaths scans Go files and validates route policy wiring statically.
Click to show internal directories.
Click to hide internal directories.